yakumo.neutron.v2.port.Manager

Package yakumo :: Package neutron :: Package v2 :: Module port :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for ports in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for ports in Networking V2 API

Instance Methods | [hide private]
_attr2json(self, attrs) | source code
_json2attr(self, json_params) | source code
yakumo.neutron.v2.port.Resource |
create(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, device=`'``__UNDEF__``'`, device_owner=`'``__UNDEF__``'`, allowed_address_pairs=`'``__UNDEF__``'`, mac_address=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a port | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_find_gen`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``port``'``
| _json_resources_key = ``'``ports``'``
| _url_resource_path = ``'``/v2.0/ports``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _attr2json(self, attrs) | source code
Overrides: base.Manager._attr2json

### _json2attr(self, json_params) | source code
Overrides: base.Manager._json2attr

### create(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, device=`'``__UNDEF__``'`, device_owner=`'``__UNDEF__``'`, allowed_address_pairs=`'``__UNDEF__``'`, mac_address=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a port Parameters: `name` (str) - Port name `network` (yakumo.neutron.v2.network.Resource) - Network `project` (yakumo.project.Resource) - Project `device` (Resource object) - Attached device (server, router, floating IP, ...) `device_owner` (str) - Device owner `allowed_address_pairs` (str) - Allowed address pairs `mac_address` (str) - MAC address `fixed_ips` (str) - Fixed IP addresses `security_groups` (str) - Security groups `is_enabled` (bool) - Whether the port is enabled Returns: yakumo.neutron.v2.port.Resource Created port Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('network', 'network_id', mapper.Resource('neu
      tron.network')), ('project', 'tenant_id', mapper.Resource('project')),
       ('device', 'device_id', mapper.Noop), ('device_owner', 'device_owner'
      , mapper.Noop), ('allowed_address_pairs', 'allowed_address_pairs', map
      per.Noop), ('mac_address', 'mac_address', mapper.Noop), ('fixed_ips',
      'fixed_ips', mapper.List(mapper.Dict(FIXED_IP_MAPPING))), ('security_g
      roups', 'security_groups', mapper.Noop), ('is_enabled', 'admin_state_u
      ...